import "core-js/modules/es.array.map.js";
import "core-js/modules/es.regexp.exec.js";
import "core-js/modules/es.string.match.js";
import "core-js/modules/es.number.constructor.js";
import "core-js/modules/es.array.join.js";
import "core-js/modules/es.string.pad-start.js";
import "core-js/modules/es.date.to-string.js";
import "core-js/modules/es.object.to-string.js";
import "core-js/modules/es.regexp.to-string.js";
import "core-js/modules/es.array.includes.js";
import "core-js/modules/es.string.includes.js";
import "core-js/modules/es.string.replace.js";
import "core-js/modules/es.string.trim.js";
import "core-js/modules/es.string.split.js";
import "core-js/modules/es.string.repeat.js";
import "core-js/modules/es.parse-int.js";

var ColorUtil = /*#__PURE__*/function () {
  function ColorUtil() {
    throw new Error('静态工具类禁止实例化');
  }
  /**
   * 线性渐变颜色，横向渐变 [0, 0] -> [1, 0], 纵向渐变 [0, 0] -> [0, 1]
   * @param colors
   * @param start [0, 0]
   * @param end [1, 0]
   */


  ColorUtil.generateLinearColor = function generateLinearColor(colors, start, end) {
    if (start === void 0) {
      start = [0, 0];
    }

    if (end === void 0) {
      end = [1, 0];
    }

    var _start = start,
        x = _start[0],
        y = _start[1];
    var _end = end,
        x2 = _end[0],
        y2 = _end[1];
    var step = 1 / (colors.length - 1);
    var colorStops = colors.map(function (color, index) {
      if (typeof color === 'string') {
        return {
          offset: Math.min(Math.round(step * index * 100) / 100, 1),
          color: color
        };
      }

      return color;
    });
    return {
      type: 'linear',
      x: x,
      y: y,
      x2: x2,
      y2: y2,
      colorStops: colorStops,
      global: false
    };
  }
  /**
   * 径向渐变颜色，从圆心 [0.5, 0.5] 按照半径 0.5 来渐变
   * @param colors
   * @param r 半径 0.5
   * @param center 圆心 [0.5, 0.5]
   */
  ;

  ColorUtil.generateRadialColor = function generateRadialColor(colors, r, center) {
    if (r === void 0) {
      r = 0.5;
    }

    if (center === void 0) {
      center = [0.5, 0.5];
    }

    var _center = center,
        x = _center[0],
        y = _center[1];
    var step = 1 / (colors.length - 1);
    var colorStops = colors.map(function (color, index) {
      if (typeof color === 'string') {
        return {
          offset: Math.min(Math.round(step * index * 100) / 100, 1),
          color: color
        };
      }

      return color;
    });
    return {
      type: 'radial',
      x: x,
      y: y,
      r: r,
      colorStops: colorStops,
      global: false
    };
  }
  /**
   * 纹理填充的颜色
   * @param image
   * @param repeat
   */
  ;

  ColorUtil.generateImageColor = function generateImageColor(image, repeat) {
    return {
      image: image,
      repeat: repeat === true ? 'repeat' : repeat === 'x' ? 'repeat-x' : repeat === 'y' ? 'repeat-y' : 'no-repeat'
    };
  }
  /**
   * 16进制色值转为rgb色值
   * @param color 16进制色值
   */
  ;

  ColorUtil.transRgb2Hex = function transRgb2Hex(color) {
    var _color$match;

    var rgbArr = (_color$match = color.match(/[\d.]+/g)) === null || _color$match === void 0 ? void 0 : _color$match.map(Number);

    if (rgbArr.length === 3) {
      return "#" + rgbArr.map(function (num) {
        return num.toString(16).padStart(2, '0');
      }).join('');
    }

    return color;
  }
  /**
   * rgb色值转为16进制色值
   * @param color rgb色值
   */
  ;

  ColorUtil.transHex2Rgb = function transHex2Rgb(color) {
    if (!color.includes('#')) return color;
    var colorString = color.trim().replace('#', '');

    if (colorString.length === 3) {
      colorString = colorString.split('').map(function (s) {
        return s.repeat(2);
      }).join('');
    }

    var colorArr = colorString.toLowerCase().match(/[a-z0-9]{2}/g);
    return "rgb(" + colorArr.map(function (c) {
      return parseInt('0x' + c);
    }).join(', ') + ")";
  }
  /**
   * 根据背景色转换rgba色值
   * @param color rgba色值
   * @param bkg 背景色值（色值不能有rgba）
   */
  ;

  ColorUtil.transRgba2Rgb = function transRgba2Rgb(color, bkg) {
    if (!color.includes('rgba')) return color;

    if (!bkg.includes('rgba')) {
      var _color$match2;

      var rgbaArr = (_color$match2 = color.match(/[\d.]+/g)) === null || _color$match2 === void 0 ? void 0 : _color$match2.map(Number);

      if ((rgbaArr === null || rgbaArr === void 0 ? void 0 : rgbaArr.length) === 4 && !bkg.includes('rgba')) {
        var _ColorUtil$transHex2R;

        var alpha = rgbaArr[3];
        var rgb = (_ColorUtil$transHex2R = ColorUtil.transHex2Rgb(bkg).match(/[\d.]+/g)) === null || _ColorUtil$transHex2R === void 0 ? void 0 : _ColorUtil$transHex2R.map(Number) //Color = Color * alpha + bkg * (1 - alpha);
        .map(function (b, index) {
          return rgbaArr[index] * alpha + b * (1 - alpha);
        }).join(', ');
        return "rgb(" + rgb + ")";
      }
    }

    return color;
  };

  return ColorUtil;
}();

export default ColorUtil;