import { ZRColor } from 'echarts/types/dist/shared';
declare type ColorStop = string | {
    offset: number;
    color: string;
};
declare class ColorUtil {
    constructor();
    /**
     * 线性渐变颜色，横向渐变 [0, 0] -> [1, 0], 纵向渐变 [0, 0] -> [0, 1]
     * @param colors
     * @param start [0, 0]
     * @param end [1, 0]
     */
    static generateLinearColor(colors: ColorStop[], start?: [number, number], end?: [number, number]): ZRColor;
    /**
     * 径向渐变颜色，从圆心 [0.5, 0.5] 按照半径 0.5 来渐变
     * @param colors
     * @param r 半径 0.5
     * @param center 圆心 [0.5, 0.5]
     */
    static generateRadialColor(colors: ColorStop[], r?: number, center?: [number, number]): ZRColor;
    /**
     * 纹理填充的颜色
     * @param image
     * @param repeat
     */
    static generateImageColor(image: HTMLImageElement | HTMLCanvasElement, repeat?: boolean | 'x' | 'y'): ZRColor;
    /**
     * 16进制色值转为rgb色值
     * @param color 16进制色值
     */
    static transRgb2Hex(color: string): string;
    /**
     * rgb色值转为16进制色值
     * @param color rgb色值
     */
    static transHex2Rgb(color: string): string;
    /**
     * 根据背景色转换rgba色值
     * @param color rgba色值
     * @param bkg 背景色值（色值不能有rgba）
     */
    static transRgba2Rgb(color: string, bkg: string): string;
}
export default ColorUtil;
